==> nlpashto-0.0.20-py3-none-any.whl: nlpashto/pashto.py <==
alphabits=[
    "ا",
    "ء",
    "ٱ",
    "ٳ",
    "ٴ",
    "ﺍ",
    "آ",
    "ب",
    "ݓ",
    "ݕ",
    "ٻ",
    "ٮ",
    "پ",
    "ة",
    "ۃ",
    "ت",
    "ٺ",
    "ٿ",
    "ټ",
    "ٽ",
    "ٹ",
    "ث",
    "ج",
    "چ",
    "ح",
    "ځ",
    "ڂ",
    "ݗ",
    "څ",
    "خ",
    "د",
    "ڋ",
    "ڈ",
    "ډ",
    "ڊ",
    "ذ",
    "ر",
    "ڕ",
    "ۯ",
    "ڔ",
    "ږ",
    "ݛ",
    "ڑ",
    "ړ",
    "ز",
    "ژ",
    "س",
    "ښ",
    "ش",
    "ص",
    "ض",
    "ط",
    "ظ",
    "ع",
    "ڠ",
    "ݟ",
    "غ",
    "ف",
    "ڤ",
    "ق",
    "ك",
    "ګ",
    "ڬ",
    "ک",
    "ݢ",
    "ڪ",
    "گ",
    "ڰ",
    "ڳ",
    "ل",
    "ݪ",
    "ﻻ",
    "ﻹ",
    "م",
    "ݦ",
    "ں",
    "ن",
    "ڼ",
    "ݧ",
    "ݩ",
    "ڹ",
    "ڽ",
    "ه",
    "ہ",
    "ھ",
    "ۂ",
    "و",
    "ۄ",
    "ۏ",
    "ؤ",
    "ٶ",
    "ۅ",
    "ۇ",
    "ۉ",
    "ې",
    "ۍ",
    "ى",
    "ي",
    "ێ",
    "ۑ",
    "ے",
    "ی",
    "ؽ",
    "ئ",
    "ۓ",
    "ٸ",
    "ە",
    "ۀ"
  ]
diacritics=[
    "߬",
    "۬",
    "ؑ",
    "ؒ",
    "ؓ",
    "ؔ",
    "ۛ",
    "ٖ",
    "ٗ",
    "ؐ",
    "ۙ",
    "ۤ",
    "ۡ",
    "ۚ",
    "ۘ",
    "ٕ",
    "ٔ",
    "ٓ",
    "ۭ",
    "ۢ",
    "ً",
    "ٌ",
    "ٍ",
    "َ",
    "ُ",
    "ِ",
    "ْ",
    "ّ",
    "ٰ",
    "ٙ",
    "ٞ",
    "۟",
    "ۖ",
    "ۗ",
    "ঁ",
    "্"
  ]
numbers=[
    "۰",
    "۱",
    "۲",
    "۳",
    "۴",
    "۵",
    "۶",
    "۷",
    "۸",
    "۹"
  ]
sentence_delimiters=['.','۔']
punctuations=[
    "﮼",
    "'",
    "\"",
    "(",
    ")",
    ",",
    ".",
    "`",
    "،",
    "؛",
    "؟",
    "٫",
    "٬",
    "۔",
    "‘",
    "’",
    "“",
    "”",
    "„",
    "‹",
    "›",
    "«",
    "»",
    "ܝ",
    "!"
]+sentence_delimiters

specials=[
    "﴾",
    "﴿",
    "٪",
    "﷽",
    "ﷻ",
    "ﷺ",
    "ﷲ",
    "ﷴ",
    "#",
    "@",
    "%",
    "٪",
    "=",
    "*",
    "$",
    "?",
    "|",
    "}",
    "{",
    "]",
    "[",
  ]

aesthetics='ـ'
unknown='-'

==> nlpashto-0.0.24-py3-none-any.whl: nlpashto/pashto.py <==
alphabits=[
    "ا",
    "ء",
    "ٱ",
    "ٳ",
    "ٴ",
    "ﺍ",
    "آ",
    "ب",
    "ݓ",
    "ݕ",
    "ٻ",
    "ٮ",
    "پ",
    "ة",
    "ۃ",
    "ت",
    "ٺ",
    "ٿ",
    "ټ",
    "ٽ",
    "ٹ",
    "ث",
    "ج",
    "چ",
    "ح",
    "ځ",
    "ڂ",
    "ݗ",
    "څ",
    "خ",
    "د",
    "ڋ",
    "ڈ",
    "ډ",
    "ڊ",
    "ذ",
    "ر",
    "ڕ",
    "ۯ",
    "ڔ",
    "ږ",
    "ݛ",
    "ڑ",
    "ړ",
    "ز",
    "ژ",
    "س",
    "ښ",
    "ش",
    "ص",
    "ض",
    "ط",
    "ظ",
    "ع",
    "ڠ",
    "ݟ",
    "غ",
    "ف",
    "ڤ",
    "ق",
    "ك",
    "ګ",
    "ڬ",
    "ک",
    "ݢ",
    "ڪ",
    "گ",
    "ڰ",
    "ڳ",
    "ل",
    "ݪ",
    "ﻻ",
    "ﻹ",
    "م",
    "ݦ",
    "ں",
    "ن",
    "ڼ",
    "ݧ",
    "ݩ",
    "ڹ",
    "ڽ",
    "ه",
    "ہ",
    "ھ",
    "ۂ",
    "و",
    "ۄ",
    "ۏ",
    "ؤ",
    "ٶ",
    "ۅ",
    "ۇ",
    "ۉ",
    "ې",
    "ۍ",
    "ى",
    "ي",
    "ێ",
    "ۑ",
    "ے",
    "ی",
    "ؽ",
    "ئ",
    "ۓ",
    "ٸ",
    "ە",
    "ۀ"
  ]
diacritics=[
    "߬",
    "۬",
    "ؑ",
    "ؒ",
    "ؓ",
    "ؔ",
    "ۛ",
    "ٖ",
    "ٗ",
    "ؐ",
    "ۙ",
    "ۤ",
    "ۡ",
    "ۚ",
    "ۘ",
    "ٕ",
    "ٔ",
    "ٓ",
    "ۭ",
    "ۢ",
    "ً",
    "ٌ",
    "ٍ",
    "َ",
    "ُ",
    "ِ",
    "ْ",
    "ّ",
    "ٰ",
    "ٙ",
    "ٞ",
    "۟",
    "ۖ",
    "ۗ",
    "ঁ",
    "্"
  ]
numbers=[
    "۰",
    "۱",
    "۲",
    "۳",
    "۴",
    "۵",
    "۶",
    "۷",
    "۸",
    "۹"
  ]
sent_delimiters=['.','۔']
punctuations=[
    "﮼",
    "'",
    "\"",
    "(",
    ")",
    ",",
    ".",
    "`",
    "،",
    "؛",
    "؟",
    "٫",
    "٬",
    "۔",
    "‘",
    "’",
    "“",
    "”",
    "„",
    "‹",
    "›",
    "«",
    "»",
    "ܝ",
    "!"
]+sent_delimiters

specials=[
    "﴾",
    "﴿",
    "٪",
    "﷽",
    "ﷻ",
    "ﷺ",
    "ﷲ",
    "ﷴ",
    "#",
    "@",
    "%",
    "٪",
    "=",
    "*",
    "$",
    "?",
    "|",
    "}",
    "{",
    "]",
    "[",
  ]

aesthetics='ـ'
unknown='-'
